@@ -155,7 +155,7 @@ short pagelinks(int page)
 	 if (xobjs.pagelist[i]->pageinst->thisobject->parts > 0)
 	    if ((i == page) || (xobjs.pagelist[i]->filename &&
 			xobjs.pagelist[page]->filename &&
-			(!strcmp(xobjs.pagelist[i]->filename,
+			(!filecmp(xobjs.pagelist[i]->filename,
 			xobjs.pagelist[page]->filename))))
 	       count++;
 
@@ -171,6 +171,8 @@ short pagelinks(int page)
 /* mode = INDEPENDENT: independent top-level pages	*/
 /* mode = DEPENDENT: dependent pages (subcircuits)	*/
 /* mode = PAGE_DEPEND: subcircuits of the current page,	*/
+/* mode = LINKED_PAGES: subcircuits of the current	*/
+/*	page, including parameter links			*/
 /* mode = TOTAL_PAGES: independent pages + subcircuits  */
 /* mode = ALL_PAGES: all pages in xcircuit		*/
 /*							*/
@@ -187,7 +189,7 @@ short pagelinks(int page)
 short *pagetotals(int page, short mode)
 {
    int i;
-   short *counts, *icount; /* , *result; (jdk) */
+   short *counts, *icount;
 
    if (xobjs.pagelist[page]->pageinst == NULL) return NULL;
 
@@ -201,10 +203,12 @@ short *pagetotals(int page, short mode)
    /* Find all the subcircuits of this page */
 
    if (mode != ALL_PAGES)
-      findsubschems(page, xobjs.pagelist[page]->pageinst->thisobject, 0, counts);
+      findsubschems(page, xobjs.pagelist[page]->pageinst->thisobject,
+		0, counts, (mode == LINKED_PAGES) ? TRUE : FALSE);
 
    /* Check independent entries (top-level pages which are not	*/
-   /* subcircuits of another page).  Set the counts entry to -1	*/
+   /* subcircuits of another page, but have the same filename	*/
+   /* as the page we started from).  Set the counts entry to -1	*/
    /* to mark each independent page.				*/
 
    if (mode != PAGE_DEPEND)
@@ -218,7 +222,7 @@ short *pagetotals(int page, short mode)
 	       {
 	          if ((i == page) || (xobjs.pagelist[i]->filename
 			&& xobjs.pagelist[page]->filename
-			&& (!strcmp(xobjs.pagelist[i]->filename,
+			&& (!filecmp(xobjs.pagelist[i]->filename,
 			xobjs.pagelist[page]->filename))))
 		     if ((mode == INDEPENDENT) || (*(counts + i) == 0))
 		        (*(icount + i))++;
@@ -228,11 +232,12 @@ short *pagetotals(int page, short mode)
    /* Check other dependent entries (top-level pages which are 	*/
    /* subcircuits of any independent page).			*/
 
-   if ((mode == DEPENDENT) || (mode == TOTAL_PAGES))
+   if ((mode == DEPENDENT) || (mode == TOTAL_PAGES) || (mode == LINKED_PAGES))
    {
       for (i = 0; i < xobjs.pages; i++)
 	 if ((i != page) && (*(icount + i) > 0))
-	    findsubschems(i, xobjs.pagelist[i]->pageinst->thisobject, 0, counts);
+	    findsubschems(i, xobjs.pagelist[i]->pageinst->thisobject,
+		0, counts, (mode == LINKED_PAGES) ? TRUE : FALSE);
    }
 
    if (mode == INDEPENDENT)
@@ -242,7 +247,8 @@ short *pagetotals(int page, short mode)
    }
    else
    {
-      if (mode == TOTAL_PAGES) {	/* merge dependent and independent */
+      if ((mode == TOTAL_PAGES) || (mode == LINKED_PAGES)) {
+	 /* merge dependent and independent */
 	 for (i = 0; i < xobjs.pages; i++)
 	    if (*(icount + i) > 0)
 	       (*(counts + i))++;
@@ -1582,8 +1588,6 @@ void catalog_op(int op, int x, int y)
 
 	          snap(x, y, &oldpos);
 
-		  /* setpage() will make a call to updateparams, which can	*/
-		  /* cause a crash if we have selections.			*/
 		  saveselects = areawin->selects;
 		  areawin->selects = 0;
    	          setpage(FALSE);
