@@ -724,6 +724,12 @@ void selectarea()
 
    /* Drawing of selected objects will take place when drawarea() is */
    /* executed after the button release.			     */
+
+#ifdef TCL_WRAPPER
+   if (xobjs.suspend < 0)
+      XcInternalTagCall(xcinterp, 2, "select", "here");
+#endif
+
 }
 
 /*------------------------*/
@@ -826,6 +832,11 @@ void clearselects_noundo()
          setdefaultfontmarks();
 	 setparammarks(NULL);
       }
+
+#ifdef TCL_WRAPPER
+      if (xobjs.suspend < 0)
+         XcInternalTagCall(xcinterp, 2, "unselect", "all");
+#endif
    }
 }
 
@@ -853,11 +864,6 @@ void unselect_all()
       draw_normal_selected(topobject, areawin->topinstance);
    clearselects();
 
-#ifdef TCL_WRAPPER
-   if (xobjs.suspend < 0)
-      Tcl_Eval(xcinterp, "xcircuit::updateparams");
-#endif
-
 }
 
 /*----------------------------------------------------------------------*/
@@ -1345,7 +1351,7 @@ short *recurse_select_element(short class, u_char mode) {
 
 #ifdef TCL_WRAPPER
    if (xobjs.suspend < 0)
-      Tcl_Eval(xcinterp, "xcircuit::updateparams");
+      XcInternalTagCall(xcinterp, 2, "select", "here");
 #endif
 
    return areawin->selectlist;
